.. py-horned-owl documentation master file, created by
   sphinx-quickstart on Wed Jan 10 09:18:12 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to py-horned-owl's documentation!
=========================================

Py-Horned-OWL is a library for Web Ontology Language in Python created using a bridge from `Horned OWL <https://github.com/phillord/horned-owl>`_ to Python using `PyO3 <https://pyo3.rs>`_. It supports loading, creation, modification, and saving of OWL2 ontologies using the optimized Horned-OWL Rust library.

Contents
--------

.. toctree::
   :maxdepth: 2

   quickstart
   installation
   usage
   performance
   details
   api

